===========
filtermaker
===========

.. image:: https://img.shields.io/pypi/v/filtermaker.svg
    :target: https://pypi.org/project/filtermaker/
    :alt: PyPI Version

.. image:: https://github.com/yukihira1992/filtermaker/actions/workflows/test-package.yml/badge.svg
    :target: https://github.com/yukihira1992/filtermaker/actions
    :alt: Build status


Make a text file filter


Installation
============

Installing from PyPI::

    pip install --upgrade filtermaker


Usage
=====
